SharedPreferencesHelper class

Constructors

SharedPreferencesHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

sharedPreferences ↔ SharedPreferences?
getter/setter pair

Static Methods

clearData({required String key}) Future<bool>?
getData({required String key}) → dynamic
init() → dynamic
putBoolean(String key, bool value) Future<bool?>
saveData({required String key, required dynamic value}) Future<bool?>
saveUserData({required String name, required String email, required String conversationId}) Future<void>