ColorsManager class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- appBarColor → const Color
- backGround → const Color
- backGroundContColor → const Color
- backGroundLogin → const Color
- backGroundPhoto2Color → const Color
- backGroundPhotoColor → const Color
- backIconColor → const Color
- backIconsColor → const Color
- backMainColor → const Color
- baseTextColor → const Color
- blackColor → const Color
- bubbleChatColor → const Color
- circleColor → const Color
- circleHomeColor → const Color
- disableButtonColor → const Color
- disableFavColor → const Color
- dollarColor → const Color
- drawerColor → const Color
- dropedColor → const Color
- greenColor → const Color
- greyColor → const Color
- hintColor → const Color
- iconBackColor → const Color
- iconBottomBarColor → const Color
- iconColor → const Color
- iconHelpColor → const Color
- mainColor → const Color
- messageTextColor → const Color
- redColor → const Color
- sideColor → const Color
- starColor → const Color
- staticTextColor → const Color
- titleTextColor → const Color
- whiteColor → const Color