CustomTextFormField class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CustomTextFormField
Constructors
- CustomTextFormField({String? hintTxt, OutlineInputBorder? out, Function? onSaved, Function? validator, IconData? suffexIcon, Function? onPressedSuffexIcon, Function? onPressedPrefexIcon, Function? onSubmitted, TextInputType? keyboardType, double? radius, Color? colorBorder, String? label, TextStyle? hintStyle, TextStyle? labelStyle, TextEditingController? controller, Function? onChange, double? fontSize = 16, Color? colorBorderEnable = Colors.black, Color? suffexIconColor, Color? prefexIconColor, FontWeight? fontWeight = FontWeight.w600, bool? obscureText = false, int? maxLines = 1, int? minLines = 1, String? helperText = '', IconData? prefexIcon, double? contentPadding = 12, TextAlign? textAlign = TextAlign.right, TextDirection? textDirection = TextDirection.rtl, String? prefexTxt, double? elevation, Color? fillColor, FocusNode? focusNode})
Properties
- colorBorder → Color?
-
final
- colorBorderEnable → Color?
-
final
- contentPadding → double?
-
final
- controller → TextEditingController?
-
final
- elevation → double?
-
final
- fillColor → Color?
-
final
- focusNode → FocusNode?
-
final
- fontSize → double?
-
final
- fontWeight → FontWeight?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
final
- hintStyle → TextStyle?
-
final
- hintTxt → String?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
final
- label → String?
-
final
- labelStyle → TextStyle?
-
final
- maxLines → int?
-
final
- minLines → int?
-
final
- obscureText → bool?
-
final
- onChange → Function?
-
final
- onPressedPrefexIcon → Function?
-
final
- onPressedSuffexIcon → Function?
-
final
- onSaved → Function?
-
final
- onSubmitted → Function?
-
final
- out → OutlineInputBorder?
-
final
- prefexIcon → IconData?
-
final
- prefexIconColor → Color?
-
final
- prefexTxt → String?
-
final
- radius → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suffexIcon → IconData?
-
final
- suffexIconColor → Color?
-
final
- textAlign → TextAlign?
-
final
- textDirection → TextDirection?
-
final
- validator → Function?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited