FontSize class
Constructors
- FontSize()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- s5 → const double
- s8 → const double
- s9 → const double
- s10 → const double
- s12 → const double
- s13 → const double
- s14 → const double
- s15 → const double
- s16 → const double
- s18 → const double
- s19 → const double
- s20 → const double
- s24 → const double
- s28 → const double
- s30 → const double
- s32 → const double