Routes class
Constructors
- Routes()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- address → const String
- allChat → const String
- booking → const String
- category → const String
- chat → const String
- dateTime → const String
- drawer → const String
- favorite → const String
- help → const String
- home → const String
- login → const String
- newPass → const String
- offers → const String
- onBoarding → const String
- otp → const String
- otpNewPass → const String
- payment → const String
- personalInfo → const String
- recipt → const String
- register → const String
- resetPass → const String
- setting → const String
- splashScreen → const String